



[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/)
[![Documentation Status](https://readthedocs.org/projects/conqace/badge/?version=latest)](https://conqace.readthedocs.io/en/latest/?badge=latest)

![Conqace](./conqase.png)

A simple python script that takes care of updates for you, and then sends a push notification to your phone when completed!


## Authors

- [@FluxC0](https://www.github.com/FluxC0)


## Installation

Ensure you have a [Pushed app key & secret](https://pushed.co) ready, as you will be prompted for them on startup.


    
